====
pyha
====


.. image:: https://img.shields.io/pypi/v/pyha.svg
        :target: https://pypi.python.org/pypi/pyha

.. image:: https://img.shields.io/travis/petspats/pyha.svg
        :target: https://travis-ci.org/petspats/pyha

.. image:: https://readthedocs.org/projects/pyha/badge/?version=develop
    :target: http://pyha.readthedocs.io/en/develop/?badge=develop
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/petspats/pyha/shield.svg
     :target: https://pyup.io/repos/github/petspats/pyha/
     :alt: Updates

.. image:: https://coveralls.io/repos/github/petspats/pyha/badge.svg?branch=develop
    :target: https://coveralls.io/github/petspats/pyha?branch=develop

..
    .. image:: https://landscape.io/github/petspats/pyha/develop/landscape.svg?style=flat
   :target: https://landscape.io/github/petspats/pyha/develop
   :alt: Code Health

.. image:: https://codeclimate.com/github/petspats/pyha/badges/gpa.svg
   :target: https://codeclimate.com/github/petspats/pyha
   :alt: Code Climate

* Free software: Apache Software License 2.0
* Documentation: https://pyha.readthedocs.io.
